@@ -6,9 +6,12 @@ from fab_deploy.utils import inside_project
 
 @inside_project
 def manage(command):
+    """ Runs django management command. """
     run('python ./manage.py '+ command)
 
 def migrate(params='', do_backup=True):
+    """ Runs migrate management command. Database backup is performed
+    before migrations if ``do_backup=False`` is not passed. """
     if do_backup:
         backup_dir = env.conf['ENV_DIR']+'/var/backups/before-migrate'
         run('mkdir -p '+ backup_dir)
@@ -16,6 +19,7 @@ def migrate(params='', do_backup=True):
     manage('migrate --noinput %s' % params)
 
 def syncdb(params=''):
+    """ Runs syncdb management command. """
     manage('syncdb --noinput %s' % params)
 
 def compress(params=''):
@@ -24,6 +28,7 @@ def compress(params=''):
 
 @inside_project
 def test(what=''):
+    """ Runs 'runtests.sh' script from project root. """
     with settings(warn_only=True):
         run('./runtests.sh ' + what)
 
