@@ -6,12 +6,13 @@ from fabric.contrib.files import append
 from fab_deploy.utils import run_as
 
 def prepare_server():
-    """ Prepares server: installs system packages """
+    """ Prepares server: installs system packages. """
     setup_backports()
     install_common_software()
 
 @run_as('root')
 def install_common_software():
+    """ Installs common system packages. """
     to_install = [
         'python2.5', 'build-essential', 'python-dev', 'python-setuptools',
         'python-profiler', 'libjpeg-dev', 'libmysqlclient15-dev', 'zlib1g-dev',
@@ -35,13 +36,14 @@ def install_common_software():
 
 @run_as('root')
 def setup_backports():
+    """ Adds backports repo to apt sources. """
     run("echo 'deb http://backports.debian.org/debian-backports lenny-backports main contrib non-free' > /etc/apt/sources.list.d/backports.sources.list")
     with settings(warn_only=True):
         run('aptitude update')
 
 @run_as('root')
 def create_linux_account(pub_key_file):
-    """ Creates linux account and setups ssh access """
+    """ Creates linux account and setups ssh access. """
     with open(os.path.normpath(pub_key_file), 'rt') as f:
         ssh_key = f.read()
     username = env.conf['USER']
@@ -53,7 +55,7 @@ def create_linux_account(pub_key_file):
             run('chown -R %s:%s .ssh' % (username, username))
 
 def ssh_add_key(pub_key_file):
-    """ Adds a ssh key from passed file to user's authorized_keys on server """
+    """ Adds a ssh key from passed file to user's authorized_keys on server. """
     with open(os.path.normpath(pub_key_file), 'rt') as f:
         ssh_key = f.read()
     append('.ssh/authorized_keys', ssh_key)
@@ -61,6 +63,7 @@ def ssh_add_key(pub_key_file):
 
 @run_as('root')
 def aptitude_install(packages, repo=None, update=False, options=''):
+    """ Installs package via aptitude. """
     if update:
         with settings(warn_only=True):
             run('aptitude update')
