@@ -3,8 +3,21 @@ from functools import wraps
 from fabric.context_managers import prefix, cd
 from fabric.contrib.files import upload_template
 from fabric.api import env, run
+from fabric.state import _AttributeDict
 
 def run_as(user):
+    """
+    Decorator. Runs fabric command as specified user. It is most useful to
+    run commands that require root access to server::
+
+        from fabric.api import run
+        from fab_deploy.utils import run_as
+
+        @run_as('root')
+        def aptitude_update():
+            run('aptitude update')
+
+    """
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
@@ -24,17 +37,36 @@ def upload_config_template(name, to=None):
     upload_template('./config_templates/' + name, to, env.conf, True)
 
 def update_env():
-    HOME_DIR = '/home/%s' % env.user
+    """
+    Updates :attr:`env.conf` configuration with some defaults and converts
+    it to _AttributeDict (that's a dictionary subclass enabling attribute
+    lookup/assignment of keys/values).
 
+    Call :func:`update_env` at the end of each server-configuring function.
+
+    ::
+
+        from fab_deploy import *
+
+        def my_site():
+            env.hosts = ['example.com']
+            env.user = 'example'
+            env.conf = dict(
+                DB_PASSWORD = 'password',
+            )
+            update_env()
+    """
+
+    HOME_DIR = '/home/%s' % env.user
     if 'INSTANCE_NAME' not in env.conf:
         env.conf['INSTANCE_NAME'] = env.user
 
-    defaults = dict(
+    defaults = _AttributeDict(
         HG_BRANCH = 'default',
         DB_NAME = env.conf['INSTANCE_NAME'],
         DB_USER = 'root',
         PROCESSES = 1,
-        THREADS = 5,
+        THREADS = 15,
         HOME_DIR = HOME_DIR,
         ENV_DIR = HOME_DIR + '/envs/' + env.conf['INSTANCE_NAME'],
         SRC_DIR = HOME_DIR + '/src/' + env.conf['INSTANCE_NAME'],
@@ -48,7 +80,7 @@ def update_env():
 
 def virtualenv():
     """
-    Context manager. Use it for perform actions inside virtualenv:
+    Context manager. Use it for perform actions inside virtualenv::
 
         with virtualenv():
             # virtualenv is active here
@@ -58,7 +90,7 @@ def virtualenv():
 
 def inside_virtualenv(func):
     """
-    Decorator. Use it for perform actions inside virtualenv:
+    Decorator. Use it for perform actions inside virtualenv::
 
         @inside_virtualenv
         def my_command():
@@ -74,12 +106,16 @@ def inside_virtualenv(func):
 def inside_project(func):
     """
     Decorator. Use it to perform actions inside project dir with
-    virtualenv activated:
+    virtualenv activated::
+
+        from fabric.api import *
+        from fab_deploy.utils import inside_project
 
         @inside_project
-        def my_command():
+        def cleanup():
             # the current dir is a project source dir and
             # virtualenv is activated
+            run('python manage.py cleanup')
 
     """
     @wraps(func)
